# ifndef yyInterProc
# define yyInterProc

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"
# include "CallGraph.h"


extern void (* InterProc_Exit) ARGS ((void));

extern void Interprocedural ARGS ((tTree t));

extern void BeginInterProc ARGS ((void));
extern void CloseInterProc ARGS ((void));

# endif
